==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/siterouting/routingprotocols/routingprotocol/ospf/shamlinks/ShamLinkKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siterouting.routingprotocols.routingprotocol.ospf.shamlinks;

import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.SvcId;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of shamLink.
 */
public class ShamLinkKeys implements KeyInfo<DefaultShamLink> {
    protected SvcId targetSite;
    /**
     * Returns the attribute targetSite.
     *
     * @return targetSite value of targetSite
     */
    public SvcId targetSite() {
        return targetSite;
    }

    /**
     * Sets the value to attribute targetSite.
     *
     * @param targetSite value of targetSite
     */
    public void targetSite(SvcId targetSite) {
        this.targetSite = targetSite;
    }


    @Override
    public int hashCode() {
        return Objects.hash(targetSite);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof ShamLinkKeys) {
            ShamLinkKeys other = (ShamLinkKeys) obj;
            return
                Objects.equals(targetSite, other.targetSite);
        }
        return false;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/siterouting/routingprotocols/routingprotocol/ospf/shamlinks/ShamLinkKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.siterouting.routingprotocols.routingprotocol.ospf.shamlinks;

import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.SvcId;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of shamLink.
 */
public class ShamLinkKeys implements KeyInfo<DefaultShamLink> {
    protected SvcId targetSite;
    /**
     * Returns the attribute targetSite.
     *
     * @return targetSite value of targetSite
     */
    public SvcId targetSite() {
        return targetSite;
    }

    /**
     * Sets the value to attribute targetSite.
     *
     * @param targetSite value of targetSite
     */
    public void targetSite(SvcId targetSite) {
        this.targetSite = targetSite;
    }


    @Override
    public int hashCode() {
        return Objects.hash(targetSite);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof ShamLinkKeys) {
            ShamLinkKeys other = (ShamLinkKeys) obj;
            return
                Objects.deepEquals(targetSite, other.targetSite);
        }
        return false;
    }
}
